@@ -21,13 +21,13 @@
 
     // abbreviate at last blank before length and add "\u2026" (horizontal ellipsis)
     function abbreviateText(text, length) {
-        var abbreviated = decodeURIComponent(text);
+        var abbreviated = text;
         if (abbreviated.length <= length) {
             return text;
         }
 
         var lastWhitespaceIndex = abbreviated.substring(0, length - 1).lastIndexOf(' ');
-        abbreviated = encodeURIComponent(abbreviated.substring(0, lastWhitespaceIndex)) + "\u2026";
+        abbreviated = abbreviated.substring(0, lastWhitespaceIndex) + "…";
 
         return abbreviated;
     }
@@ -43,19 +43,16 @@
     // fallback to content of <title> tag
     function getTweetText() {
         var text = '';
-        var description = getMeta('DC.description');
-        var title = getMeta('DC.title');
-        var creator = getMeta('DC.creator');
+        var description = $.trim(getMeta('DC.description') || getMeta('description'));
+        var title = $.trim(getMeta('DC.title') || $('.documentFirstHeading').text() || $('title').text());
 
         if (description.length > 0) {
-            text = description;
-        } else if (title.length > 0 && creator.length > 0) {
-            text = title + ' - ' + creator;
+            text = title + ' - ' + description;
         } else {
             text = $('title').text();
         }
 
-        return encodeURIComponent(text);
+        return text;
     }
 
     // build URI from rel="canonical" or document.location
@@ -208,16 +205,38 @@
                 if (typeof text === 'function') {
                     text = text();
                 }
-                // 120 is the max character count left after twitters automatic url shortening with t.co
-                text = abbreviateText(text, '120');
 
                 var twitter_url = options.services.twitter.short_url;
                 if (twitter_url.length == 0) {
                     twitter_url = uri;
                 }
+
+                // 140 minus additional chars
+                var url_length = (twitter_url + options.services.twitter.referrer_track).length + 2;
+                var hashtags = options.services.twitter.hashtags.split(',');
+                var hashtags_length = 0;
+                for(var i in hashtags) {
+                    var tag = hashtags[i];
+                    hashtags_length += tag.length + 2;
+                }
+
+                var text_max_length = (140 - url_length - hashtags_length);
+                if (text_max_length < 0)
+                    text_max_length = 0;
+                else if(text_max_length > 120)
+                    text_max_length = 120;
+
+                console.log("text: " + text_max_length)
+                console.log("url: " + url_length)
+                console.log("tags: " + hashtags_length)
+
+                text = abbreviateText(text, text_max_length);
+
+                var text = encodeURIComponent(text);
                 var twitter_enc_uri = encodeURIComponent(twitter_url + options.services.twitter.referrer_track);
                 var twitter_count_url = encodeURIComponent(uri);
                 var twitter_hashtags = encodeURIComponent(options.services.twitter.hashtags);
+
                 var twitter_code = '<iframe allowtransparency="true" frameborder="0" scrolling="no" src="http://platform.twitter.com/widgets/tweet_button.html?url=' + twitter_enc_uri + '&amp;hashtags=' + twitter_hashtags + '&amp;counturl=' + twitter_count_url + '&amp;text=' + text + '&amp;count=horizontal&amp;lang=' + options.services.twitter.language + '" style="width:130px; height:25px;"></iframe>';
                 var twitter_dummy_btn = '<img src="' + options.services.twitter.dummy_img + '" alt="&quot;Tweet this&quot;-Dummy" class="tweet_this_dummy" />';
 
